@@ -6,7 +6,13 @@ import os
 
 
 class RepoScraping(object):
-    def __init__(self, repo_url: str, p: bool = False, save: bool = False) -> None:
+    def __init__(
+        self,
+        repo_url: str,
+        p: bool = False,
+        save: bool = False
+    ) -> None:
+
         self.repo_url = repo_url
         self.p = p
         self.save = save
@@ -54,7 +60,7 @@ class RepoScraping(object):
                 except TypeError:
                     pass
 
-    def __load_data(self):
+    def __load_data(self) -> None:
         if os.path.isfile('tree_urls.pkl'):
             with open('tree_urls.pkl', 'rb') as f:
                 self.tree_urls = pickle.load(f)
@@ -71,7 +77,10 @@ class RepoScraping(object):
         else:
             self.file_urls = []
 
-    def __remove_cache(self):
+    def __remove_cache(self) -> None:
         if self.save:
-            os.remove('tree_urls.pkl')
-            os.remove('file_urls.pkl')
+            for i in ["tree_urls.pkl", "file_urls.pkl"]:
+                try:
+                    os.remove(i)
+                except FileNotFoundError:
+                    continue
